/*
 * Zaptel sysfs support for Zapata Telephony interface
 *
 * Written by Maxime MENEAULT <maxmeneault@free.fr>
 *
 * From an idea of Tzafrir Cohen (Xorcom Ltd.)
 *
 * Copyleft (>) 2007 Maxime MENEAULT <maxmeneault@free.fr>
 *
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 *
 */
#ifndef _ZAPTEL_SYSFS_H
#define _ZAPTEL_SYSFS_H


#include "zaptel.h"
#ifdef CONFIG_ZAP_UDEV

/* @brief init the zaptel sysfs framework 
*
* register the main zaptel class and add every static device 
* (zapctl, zaptimer ...) in sysfs
*
* @returns 0 in case of success
*
* @note if an error is returned then everything has been returned in the
* previous state of the call so that zt_sysfs_destroy is unnecessary.
*
* @warning only to be called once in a program since it relies on global
* variables
*/
int zt_sysfs_init(void);

/* @brief destroy the zaptel sysfs framework 
*
* Unregister all the static devices and the main zaptel class
* 
* @warning a successfull call to zt_syfs_init must be matched with a call
* to zt_sysfs_destroy.
*
*/
void zt_sysfs_destroy(void);


/*
* @warning 
* the following functions assume that the framework has been correctly initialized
* and not yet destroyed 
*/

/* @brief register a span in sysfs 
*
* @returns 0 in case of success
* if an error is returned then after the call 
* we returned into the previous state of the call (span not registered)
*/
int zt_sysfs_span_register(struct zt_span *span);


/* @brief unregister a span in sysfs 
* 
* @warning Must be called for each successfull call to zt_sysfs_span_register
*/
void zt_sysfs_span_unregister(struct zt_span *span);



/* @brief register a channel in sysfs 
*
* As a channel is a member of a span better call zt_sysfs_span_register before
* registering a channel
*/
int zt_sysfs_channel_register(struct zt_chan *chan);


/* @brief unregister a channel in sysfs 
* better match every zt_sysfs_channel_register with a call
* to zt_sysfs_channel_unregister
*/
void zt_sysfs_channel_unregister(struct zt_chan *chan);

#endif /* CONFIG_ZAP_UDEV */

#endif /* _ZAPTEL_SYSFS_H */
